<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of defaultPost, a plugin for Dotclear 2.
#
# Copyright (c) 2010 Xavier Gouchet and contributors
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------

/* Settings */

$p_url		= 'plugin.php?p='.basename(dirname(__FILE__));

$s =& $core->blog->settings->defaultPost;
$as = unserialize($s->defaultPost_options);

if ($s->defaultPost_active) {
	$default_tab = isset($_GET['tab']) ? $_GET['tab'] : 'edit-entry';
} else {
	$default_tab = isset($_GET['tab']) ? $_GET['tab'] : 'settings';
}

$active = $s->defaultPost_active;
$post_title = $s->defaultPost_title;
$post_content = $s->defaultPost_content;
$post_excerpt = $s->defaultPost_excerpt;
$post_notes = $s->defaultPost_notes;

# Categories

$categories_combo = array('&nbsp;' => '');
try {
	$categories = $core->blog->getCategories(array('post_type'=>'post'));
	while ($categories->fetch()) {
		$categories_combo[] = new formSelectOption(
			str_repeat('&nbsp;&nbsp;',$categories->level-1).'&bull; '.html::escapeHTML($categories->cat_title),
			$categories->cat_id
		);
	}
} catch (Exception $e) { }

# Time interval combo
$time_interval_combo[__('-- time interval --')] = -1;
$time_interval_combo[__('same date')] = 0;
$time_interval_combo[__('1 minute')] = 60;
$time_interval_combo[__('5 minutes')] = 300;
$time_interval_combo[__('15 minutes')] = 900;
$time_interval_combo[__('30 minutes')] = 1800;
$time_interval_combo[__('1 hour')] = 3600;
$time_interval_combo[__('12 hours')] = 12*3600;
$time_interval_combo[__('1 day')] = 24*3600;
$time_interval_combo[__('2 days')] = 48*3600;
$time_interval_combo[__('1 week')] = 7*24*3600;
$time_interval_combo[__('2 weeks')] = 2*7*24*3600;
$time_interval_combo[__('1 month')] = 'month';

# Post format
if ($format == '') {
	$post_format = $core->auth->getOption('post_format');
} else {
	$post_format = $format;
}
foreach ($core->getFormaters() as $v) {
	$formaters_combo[$v] = $v;
}

# Status combo
foreach ($core->blog->getAllPostStatus() as $k => $v) {
	$status_combo[$v] = (string) $k;
}

# Languages combo
$rs = $core->blog->getLangs(array('order'=>'asc'));
$all_langs = l10n::getISOcodes(0,1);
$lang_combo = array('' => '', __('Most used') => array(), __('Available') => l10n::getISOcodes(1,1));
while ($rs->fetch()) {
	if (isset($all_langs[$rs->post_lang])) {
		$lang_combo[__('Most used')][$all_langs[$rs->post_lang]] = $rs->post_lang;
		unset($lang_combo[__('Available')][$all_langs[$rs->post_lang]]);
	} else {
		$lang_combo[__('Most used')][$rs->post_lang] = $rs->post_lang;
	}
}
unset($all_langs);
unset($rs);

/* Post Treatment 
 * Save activation 
 */
if (!empty($_POST['saveconfig'])) {
  try {
    $active = (empty($_POST['active']))?false:true;
    $s->put('defaultPost_active',$active,'boolean');	
    
	http::redirect($p_url.'&tab=settings&upd=1');
  } catch (Exception $e) {
    $core->error->add($e->getMessage());
  }
  
}

/* Post Treatment 
 * Post Content
 */
if (!empty($_POST['savecontent'])) {
  try {
    
    $s->put('defaultPost_title',$_POST['post_title'],'string');
    $s->put('defaultPost_content',$_POST['post_content'],'string');
	$s->put('defaultPost_excerpt',$_POST['post_excerpt'],'string');
	$s->put('defaultPost_notes',$_POST['post_notes'],'string');
	
	$post_dt = empty($_POST['post_dt']) ? '' : strtotime($_POST['post_dt']);
	
	$opts = array(
			'cat_id' => $_POST['cat_id'],
			'post_status' => $_POST['post_status'],
			'post_dt' => $post_dt,
			'post_date_next' => $_POST['post_date_next'],
			'post_format' => $_POST['post_format'],
			'post_open_comment' => $_POST['post_open_comment'] ,
			'post_open_tb' => $_POST['post_open_tb'],
			'post_selected' => $_POST['post_selected'],
			'post_lang' => $_POST['post_lang'],
			'post_password' => $_POST['post_password'],
			'post_spec_url' => $_POST['post_spec_url'],
			'default_post_tags' => $_POST['default_post_tags'],
			'default_post_pings' => $_POST['default_post_pings']
		);
		
	$s->put('defaultPost_options',serialize($opts));
	
    http::redirect($p_url.'&tab=edit-entry&upd=2');
	
  } catch (Exception $e) {
    $core->error->add($e->getMessage());
  }
  
}
?>
<html>
<head>
	<title><?php echo __('Default Post'); ?></title>

<?php echo 
	dcPage::jsDatePicker().
	dcPage::jsToolBar().
	dcPage::jsMetaEditor().
	dcPage::jsLoad(DC_ADMIN_URL.'?pf=defaultPost/js/_post.js').
	dcPage::jsConfirmClose('entry-form').
	# --BEHAVIOR-- adminPostHeaders
	$core->callBehavior('adminPostHeaders').
	dcPage::jsPageTabs($default_tab);
?>

<script type="text/javascript">
$(document).ready(function() {
	var default_post_pings = "<?php echo $as['default_post_pings']; ?>";

	var tab = default_post_pings.split(",");

	$('input[name=pings_do\[\]]').each(function(index) {
		
		
			if ($(this).val() == tab[index]) {
				$(this).attr('checked', true);
			}
		
	});
});
</script>

</head>
<body>

<?php

# Display messages

if (isset($_GET['upd']))
{
	$p_msg = '<p class="message">%s</p>';
	
	$a_msg = array(
		__('Configuration successfully updated.'),
		__('Content successfully updated.')
	);
	
	$k = (integer) $_GET['upd']-1;
	
	if (array_key_exists($k,$a_msg)) {
		echo sprintf($p_msg,$a_msg[$k]);
	}
}
?>


<h2><?php echo html::escapeHTML($core->blog->name); ?> &gt; <?php echo __('Default Post'); ?></h2>


<!-- Form Display -->
<div class="multi-part" id="settings" title="<?php echo __('Settings'); ?>">
	<form method="post" action="<?php echo $p_url; ?>">
		<fieldset>
			<legend><?php echo __('Plugin activation'); ?></legend>
			
				<label class="classic">
					<?php echo form::checkbox('active', 1, $active); ?>
				&nbsp;<?php echo __('Enable default content for new posts');?>
				</label>
			
		</fieldset>
		<fieldset>
			<input type="hidden" name="p" value="defaultPost" />
			<?php echo $core->formNonce(); ?>
			<input type="submit" name="saveconfig" value="<?php echo __('Save configuration'); ?>" />
		</fieldset>
	</form>
</div>

<!-- Default Post Content -->
<div class="multi-part" id="edit-entry" title="<?php echo __('Edit'); ?>">
	<form action="<?php echo $p_url; ?>" method="post" id="entry-form">
    
		<?php 
		
		echo 
		
		'<div id="entry-sidebar">'.
		
		'<p><label>'.__('Category:').
        form::combo('cat_id',$categories_combo,$as['cat_id'],'maximal',3).
        '</label></p>'.
		
		'<p><label>'.__('Entry status:').
		form::combo('post_status',$status_combo,$as['post_status'],'',3).
		'</label></p>'.
		
		'<p><label>'.__('Published on:').
		form::field('post_dt',16,16,$as['post_dt'] == '' ?  '' : date('Y-m-d H:i:00',$as['post_dt']),'',3).
		'</label></p>'.
		
		'<p><label>'.__('Time after latest post:').
        form::combo('post_date_next',$time_interval_combo,$as['post_date_next'],'',3).
        '</label></p>'.
		
		'<p><label>'.__('Text formating:').dcPage::help('post','p_format').
        form::combo('post_format',$formaters_combo,$as['post_format'],'',3).
        '</label></p>'.
		
		'<p><label class="classic">'.form::checkbox('post_open_comment',1,$as['post_open_comment'],'',3).' '.
		__('Accept comments').'</label></p>'.
		'<p><label class="classic">'.form::checkbox('post_open_tb',1,$as['post_open_tb'],'',3).' '.
		__('Accept trackbacks').'</label></p>'.
		'<p><label class="classic">'.form::checkbox('post_selected',1,$as['post_selected'],'',3).' '.
		__('Selected entry').'</label></p>'.
		
		'<p><label>'.__('Entry lang:').
		form::combo('post_lang',$lang_combo,$as['post_lang'],'',5).
		'</label></p>'.
		
		'<p><label>'.__('Entry password:').
		form::field('post_password',10,32,html::escapeHTML($as['post_password']),'maximal',3).
		'</label></p>'.
		
		'<div class="lockable">'.
			'<p><label>'.__('Basename:').
			form::field('post_spec_url',10,255,html::escapeHTML($as['post_spec_url']),'maximal',3).
			'</label></p>'.
			'<p class="form-note warn">'.
			__('Warning: If you set the URL manually, it may conflict with another entry.').
			'</p>'.
		'</div>';
		
		# --BEHAVIOR-- adminPostFormSidebar
		$core->callBehavior('adminPostFormSidebar',isset($post) ? $post : null);
		
		echo '</div>';		// End #entry-sidebar
		
        ?>
        <div id="entry-content">
			<fieldset class="constrained">
				<?php echo
                '<p class="col"><label for="post_title">'.__('Title:').
                dcPage::help('post','p_title').
                form::field('post_title',20,255,html::escapeHTML($post_title),'maximal',2).
                '</label></p>'.
				
            	'<p class="area" id="excerpt-area"><label for="post_excerpt">'.__('Excerpt:').
                dcPage::help('post','p_excerpt').'</label> '.
                form::textarea('post_excerpt',50,5,html::escapeHTML($post_excerpt),'',2).
                '</p>'.
				
				'<p class="area" id="content-area"><label for="post_content">'.__('Content:').
				dcPage::help('post','p_content').'</label> '.
				form::textarea('post_content',50,$core->auth->getOption('edit_size'),html::escapeHTML($post_content),'',2).
				'</p>'.
				
				'<p class="area" id="notes-area"><label>'.__('Notes:').'</label>'.
				form::textarea('post_notes',50,5,html::escapeHTML($post_notes),'',2).
				'</p>'.

				'<textarea cols="50" rows="5" name="default_post_tags" id="default_post_tags" style="display:none;">'.$as['default_post_tags'].'</textarea>'.
				'<textarea cols="50" rows="5" name="default_post_pings" id="default_post_pings" style="display:none;">'.$as['default_post_pings'].'</textarea>';
				?>
			</fieldset>
			<fieldset>
				<input type="submit" tabindex="4" accesskey="s" name="savecontent" value="<?php echo __('save')?>" />
				<?php echo $core->formNonce(); ?>
			</fieldset>
		</div>
	</form>
		
</div>


<?php 
dcPage::helpBlock('defaultPost','core_wiki');
?>
</body>
</html>
